@@ -168,7 +168,7 @@ typedef enum zimg_cpu_type_e {
 	ZIMG_CPU_X86_F16C       = 1008, /**< AVX with F16C extension (e.g. Ivy Bridge). */
 	ZIMG_CPU_X86_AVX2       = 1009,
 	ZIMG_CPU_X86_AVX512F    = 1010,
-	ZIMG_CPU_X86_AVX512_SKL = 1011  /**< AVX-512 {F,CD,VL,BW,DQ} (e.g. Skylake-X/SP). */
+	ZIMG_CPU_X86_AVX512_SKX = 1011  /**< AVX-512 {F,CD,VL,BW,DQ} (e.g. Skylake-X/SP). */
 #endif
 } zimg_cpu_type_e;
 
@@ -351,6 +351,7 @@ typedef enum zimg_resample_filter_e {
 	ZIMG_RESIZE_BICUBIC  = 2, /**< Bicubic convolution (separable) filter. */
 	ZIMG_RESIZE_SPLINE16 = 3, /**< "Spline16" filter from AviSynth. */
 	ZIMG_RESIZE_SPLINE36 = 4, /**< "Spline36" filter from AviSynth. */
+	ZIMG_RESIZE_SPLINE64 = 6, /**< "Spline64" filter from AviSynth. */
 	ZIMG_RESIZE_LANCZOS  = 5  /**< Lanczos resampling filter with variable number of taps. */
 } zimg_resample_filter_e;
 
@@ -374,10 +375,10 @@ typedef enum zimg_resample_filter_e {
   * instances will not read or write beyond image bounds, and no padding is
   * necessary.
   *
-  * The image stride must be a multiple of the alignment imposed by the host
-  * CPU architecture. On x86 and AMD64, this is 32 bytes. When operating in
-  * 64-byte mode ({@link ZIMG_CPU_AUTO_64B}), the alignment requirement is
-  * increased to 64 bytes. The stride may be negative.
+  * The image address and stride must be a multiple of the alignment imposed
+  * by the host CPU architecture. On x86 and AMD64, this is 32 bytes. When
+  * operating in 64-byte mode ({@link ZIMG_CPU_AUTO_64B}), the alignment
+  * requirement is increased to 64 bytes. The stride may be negative.
   */
 typedef struct zimg_image_buffer_const {
 	unsigned version; /**< @see ZIMG_API_VERSION */
